@@ -6,7 +6,7 @@ df = pd.read_csv("iedb_allele_counts.csv")
 alleles = set()
 special_chars = " *:-,/."
 with open(TEST_FILENAME, "w") as f:
-    f.write("from mhcgnomes import parse")
+    f.write("from mhcgnomes import parse\n")
     for allele_name, count in sorted(zip(
             df.allele, df["number_of_entries"])):
         if allele_name in alleles:
@@ -20,7 +20,7 @@ with open(TEST_FILENAME, "w") as f:
 
         f.write(f"\ndef test_{fn_name}():")
         f.write(f"\n    # {allele_name} occurs {count} times in 2019 IEDB snapshot")
-        f.write(f"\n    parse(\"{allele_name}\")")
+        f.write(f"\n    assert parse(\"{allele_name}\") is not None")
         f.write("\n")
 
 print("Wrote %d alleles to %s" % (len(alleles), TEST_FILENAME))
\ No newline at end of file
